'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = runAllTests;

var _logging = require('../logging');

var _one = require('./one');

var _one2 = _interopRequireDefault(_one);

var _package = require('../../package');

var _package2 = _interopRequireDefault(_package);

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function runAllTests(versions) {
  const outputDir = '.' + _package2.default.name;
  return (0, _util.exists)(outputDir).catch(function () {
    const dirPromise = (0, _util.mkdir)(outputDir);
    dirPromise.then(function () {
      _logging.logger.debug('Directory created: %s', outputDir);
    });
    return dirPromise;
  }).then(function () {
    return Promise.all(versions.map(function (version) {
      return (0, _one2.default)(outputDir, version);
    }));
  }).then(function (results) {
    const failures = results.filter(result => result.returnCode !== 0);
    if (failures.length > 0) {
      _logging.logger.error('Test execution failed for: %s', failures.map(result => result.version));
      return Promise.resolve(1);
    }

    _logging.logger.info('Test execution success');
    return Promise.resolve(0);
  });
}