'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = runTests;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _logging = require('../logging');

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function runTests(outputDir, version) {
  const versionDir = _path2.default.join(outputDir, String(version));

  function execLog(subprocess) {
    _logging.logger.debug('[%s] command: %s', version, subprocess.command);
    _logging.logger.debug('[%s] stdout:\n%s', version, subprocess.stdout);
    _logging.logger.debug('[%s] stderr:\n%s', version, subprocess.stderr);
    return subprocess;
  }

  return (0, _util.exists)(versionDir).then(function () {
    return (0, _util.exec)('git rev-parse --abbrev-ref HEAD').then(execLog).then(function (subprocess) {
      const branchName = subprocess.stdout.trimRight();
      return (0, _util.exec)(`git fetch && git checkout --force ${ branchName } && git reset --hard origin/${ branchName } && git pull`, { shell: '/bin/bash', cwd: versionDir });
    }).then(execLog);
  }, function () {
    return (0, _util.mkdir)(versionDir).then(function () {
      _logging.logger.debug('[%s] Directory created: %s', version, versionDir);
    }).then(function () {
      return (0, _util.exec)(`git clone . ${ versionDir }`);
    }).then(execLog);
  }).then(function () {
    const command = `source ${ process.env.NVM_DIR }/nvm.sh && nvm use ${ version } && npm prune && npm install && npm test`;
    return (0, _util.exec)(command, { shell: '/bin/bash', cwd: versionDir }).then(execLog);
  }).then(function () {
    _logging.logger.info('[%s] Test case execution success', version);
    return Promise.resolve({ version, returnCode: 0 });
  }).catch(function (_ref) {
    let message = _ref.message;
    var _ref$code = _ref.code;
    let code = _ref$code === undefined ? 1 : _ref$code;

    _logging.logger.error('[%s] %s', version, message);
    return Promise.resolve({ version, returnCode: code });
  });
}