'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = parse;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _logging = require('./logging');

var _util = require('./util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function parse() {
  const travisFile = _path2.default.join(process.cwd(), '.travis.yml');
  return (0, _util.exists)(travisFile).catch(function () {
    _logging.logger.error('Travis file not found: %s', travisFile);
    return Promise.reject();
  }).then(function () {
    return (0, _util.readFile)(travisFile);
  }).then(function (data) {
    const travisConfig = _jsYaml2.default.safeLoad(data);
    if (typeof travisConfig.language === 'undefined') {
      _logging.logger.error('language field not found in travis configuration');
      return Promise.reject();
    }
    if (travisConfig.language !== 'node_js') {
      _logging.logger.error('Unexpected language in travis configuration: %s', travisConfig.language);
      return Promise.reject();
    }

    if (typeof travisConfig.node_js === 'undefined') {
      _logging.logger.error('node_js field not found in travis configuration');
      return Promise.reject();
    }

    _logging.logger.info('Node versions to use for testing: %s', travisConfig.node_js);
    return Promise.resolve(travisConfig.node_js);
  });
}